@@ -67,7 +67,7 @@ except NameError:
     unicode = str
 
 
-__version__ = "2.2.0"
+__version__ = "2.2.1"
 
 
 # If restview is ever packaged for Debian, this'll likely be changed to
@@ -339,6 +339,10 @@ window.onload = function () {
                         for (var i = old_styles.length - 1; i >= 0; i--) {
                             old_styles[i].remove();
                         }
+                        // convert HTMLCollection to an array so that
+                        // items don't disappear from under us when I append
+                        // them to a different DOM tree
+                        new_styles = [].slice.call(new_styles);
                         for (var i = 0; i < new_styles.length; i++) {
                             document.head.appendChild(new_styles[i]);
                         }
